<!--标识牌区域设备分析-->
<template>
  <div class="regional-equipment-analysis">
    <public-title title="标识牌区域设备分析">
      <template v-slot:title="{title}">
        {{ title }}
        <div v-show="historyArr.length">
          （<span v-for="(item,index) in historyArr" :key="index">
              {{ item.areaName }} {{ index !== historyArr.length - 1 ? '-' : '' }}
          </span>）
        </div>
      </template>
    </public-title>
    <div class="chart-container">
      <div id="regional-equipment-analysis-chart" style="width: 100%;height: 100%;" />
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import {areaStatusAnalyze} from '@/api/device/earlyWarningMonitoring'
import PublicTitle from '../PublicTitle/index.vue'

export default {
  name: 'RegionalEquipmentAnalysis',
  components: {PublicTitle},
  data() {
    return {
      myChart: null,  // 图表实例对象
      historyArr: [] // 下钻数据历史
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('regional-equipment-analysis-chart'))
  },
  methods: {
    /**
     * @function getChartData 获取图表数据
     * @param {String} areaId 区域Id
     * @param {Function} callback 回调函数
     * @return {void}
     * */
    async getChartData(areaId = '', callback) {
      const {value} = await areaStatusAnalyze(areaId || '', '1651838677728370688')
      if (!(Array.isArray(value) && value.length)) {
        this.$message.warning(`暂无数据`)
      } else {
        this.chartData = value
        callback && callback()
        this.$nextTick(_ => this.initEcharts())
      }
    },

    // 初始化图表
    initEcharts() {
      this.myChart.off('click')
      this.myChart.setOption({
        tooltip: {
          trigger: 'axis',
          textStyle: {  //---提示框样式
            color: '#606266',
            fontSize: '14'
          },
          axisPointer: {            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
          }
        },
        legend: {
          type: 'plain',
          position: 'center',
          textStyle: {  //---提示框样式
            color: '#606266',
            fontSize: '14'
          }
        },
        grid: {
          left: '0',
          right: '0',
          bottom: '0',
          containLabel: true
        },
        xAxis: [
          {
            type: 'category',
            axisTick: {show: true},
            axisLabel: {color: '#606266', fontSize: '14', interval: 0},
            data: this.chartData.map(i => i.areaName),
            interval: 5
          }
        ],
        yAxis: [
          {
            type: 'value',
            name: '单位（数量）',
            nameTextStyle: {
              color: '#606266',
              fontSize: '14',
              align: 'end',
              padding: [0, 0, 0, -10]
            },
            nameGap: 30,
            axisTick: {show: false},
            axisLine: {show: false},
            axisLabel: {color: '#606266', fontSize: '14'},
            // 修改y轴分割线
            splitLine: {
              lineStyle: {
                color: '#c7c7c7',
                fontSize: '14',
                type: 'dashed'
              }
            }
          }
        ],
        series: [
          {
            name: '正常数',
            type: 'bar',
            barGap: '20%',
            barWidth: '20',
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#3eadfd'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => value ? value : '',
              textStyle: { //数值样式
                color: '#3eadfd',//字体颜色
                fontSize: 12//字体大小
              }
            },
            data: this.chartData.map(i => i.normal)
          },
          {
            name: '报警数',
            type: 'bar',
            barGap: '20%',
            barWidth: '20',
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#ffda68'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => value ? value : '',
              textStyle: { //数值样式
                color: '#ffda68',//字体颜色
                fontSize: 12//字体大小
              }
            },
            data: this.chartData.map(i => i.alarm)
          },
          {
            name: '故障数',
            type: 'bar',
            barGap: '20%',
            barWidth: '20',
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#ff6e79'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => value ? value : '',
              textStyle: { //数值样式
                color: '#ff6e79',//字体颜色
                fontSize: 12//字体大小
              }
            },
            data: this.chartData.map(i => i.failure)
          }
        ],
        toolbox: {
          feature: {
            myTool: {
              show: this.historyArr.length,
              title: '返回',
              icon: 'path://M608.256 159.232l124.416-71.168c19.456-11.264 26.624-36.352 15.36-55.808-11.264-19.456-36.352-26.624-55.808-15.36L467.456 145.408c-9.216 5.632-16.384 14.336-18.944 24.576s-1.536 21.504 4.096 31.232l128.512 224.256c7.68 13.312 21.504 20.48 35.328 20.48 6.656 0 13.824-1.536 20.48-5.632 19.456-11.264 26.624-36.352 15.36-55.808l-86.016-150.016c168.96 25.6 298.496 171.52 298.496 347.136 0 193.536-157.696 351.232-351.232 351.232s-351.232-157.696-351.232-351.232c0-22.528-18.432-40.96-40.96-40.96s-40.96 18.432-40.96 40.96c0 238.592 194.048 433.152 433.152 433.152 238.592 0 433.152-194.048 433.152-433.152-0.512-206.336-145.408-379.392-338.432-422.4z',
              onclick: () => {
                this.historyArr.pop()
                this.getChartData(this.historyArr[this.historyArr.length - 1]?.areaId || '')
              }
            }
          }
        }
      })
      this.myChart.on('click', ({name}) => {
        const item = this.chartData.find(i => i.areaName === name) || {}
        if (item.areaId) this.getChartData(item.areaId, _ => this.historyArr.push(item))
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.regional-equipment-analysis {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;

  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 15px 20px;
  }
}
</style>
